@@ -67,7 +67,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_DST'	=> 'أدخل التوقيت الصيفي/<abbr title="فرق التوقيت الصيفي">DST</abbr>',
 	'SYSTEM_TIMEZONE'	=> 'منطقة توقيت النظام',
 	'WARNINGS_EXPIRE'	=> 'مدة التحذير',
-	'WARNINGS_EXPIRE_EXPLAIN'	=> 'عدد الأيام المنقضية التي تبعد التحذير من سجلات المستخدم',
+	'WARNINGS_EXPIRE_EXPLAIN'	=> 'عدد الأيام المنقضية التي تبعد التحذير من سجلات المستخدم. اجعل هذه القيمة 0 لجعل التحذيرات دائمة.',
 	'ACP_BOARD_FEATURES_EXPLAIN'	=> 'من هنا يمكنك تعطيل تفعيل بعض خصائص المنتدى',
 	'ALLOW_ATTACHMENTS'	=> 'اسمح بالمرفقات',
 	'ALLOW_BIRTHDAYS'	=> 'السماح بعيد الميلاد',
@@ -167,7 +167,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'	=> 'أقصى حد للوصلات',
 	'MAX_POST_URLS_EXPLAIN'	=> 'أقصى حد للوصلات. ضع القيمة صفر لجعل الحد لا نهائي',
 	'MIN_CHAR_LIMIT'	=> 'عدد الأحرف الأدنى في الرسالة او المشاركة',
-	'MIN_CHAR_LIMIT_EXPLAIN'	=> 'العدد الأدنى من الحروف كي يتمكن العضو من إرسال الرسالة أو المشاركة.',
+	'MIN_CHAR_LIMIT_EXPLAIN'	=> 'العدد الأدنى من الحروف كي يتمكن العضو من إرسال الرسالة أو المشاركة. أقل عدد يمكن وضعه هو 1.',
 	'POSTING'	=> 'مشاركة',
 	'POSTS_PER_PAGE'	=> 'المشاركات بالصفحة',
 	'QUOTE_DEPTH_LIMIT'	=> 'أقصى عدد للاقتباسات في المشاركة',
@@ -196,7 +196,6 @@ $lang = array_merge($lang, array(
 	'NEW_MEMBER_POST_LIMIT_EXPLAIN'	=> 'الأعضاء المُسجلين الجُدد سيكونوا ضمن مجموعة <em>الأعضاء المسجلين الجًدد</em> حتى يصل عدد مشاركاتهم إلى هذا العدد. تستطيع استخدام هذه المجموعة لاستبعادهم من استخدام الرسائل الخاصة أو مُراجعة نشاط مشاركاتهم. <strong>القيمة صفر ستعطل هذه الخاصية.</strong>',
 	'NEW_MEMBER_GROUP_DEFAULT'	=> 'ضبط مجموعة الأعضاء المسجلين الجًدد إلى الإعدادات الإفتراضية',
 	'NEW_MEMBER_GROUP_DEFAULT_EXPLAIN'	=> 'إذا اخترت "نعم" وتحديد عدد مشاركات العضو الجديد , سيضاف الأعضاء المُسجلين الجُدد إلى مجموعة <em>الأعضاء المسجلين الجًدد</em> وستكون هذه المجموعة هي المجموعة الافتراضية لهم. وعند تحديد رُتبة أو صورة شخصية إفتراضية مُخصصة لهذه المجموعة , سيتم ضبطها إفتراضياً على أعضاء هذه المجموعة.',
-
 	'ACC_ADMIN'	=> 'بواسطة مدير',
 	'ACC_DISABLE'	=> 'تعطيل التسجيل',
 	'ACC_NONE'	=> 'بدون تفعيل (المشاركة الفورية)',
