@@ -264,8 +264,20 @@ $lang = array_merge($lang, array(
 	'AVATAR_DIR_SIZE'	=> 'حجم مجلد الصور الشخصية',
 	'BOARD_STARTED'	=> 'تاريخ بداية المنتدى',
 	'BOARD_VERSION'	=> 'اصدار المنتدى',
+	
 	'DATABASE_SERVER_INFO'	=> 'خادم قاعدة البيانات',
 	'DATABASE_SIZE'	=> 'حجم قاعدة البيانات',
+	
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'               => 'إعدادات الحمل الزائد للدوال غير صحيحة',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'         => '<var>mbstring.func_overload</var> يجب أن تكون 0 أو 4. يمكنك معرفة الإعداد الحالي في صفحة <samp>PHP information</samp>.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'         => 'إعدادات ترميز الحروف الشفافة غير صحيحة',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'   => '<var>mbstring.encoding_translation</var> يجب أن تكون 0. يمكنك معرفة الإعداد الحالي في صفحة <samp>PHP information</samp>.',
+	'ERROR_MBSTRING_HTTP_INPUT'                  => 'إعدادات HTTP لتحويل الحروف المدخلة غير صحيحة',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'            => '<var>mbstring.http_input</var> يجب أن تكون <samp>pass</samp>. يمكنك معرفة الإعداد الحالي في صفحة <samp>PHP information</samp>.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'               => 'إعدادات HTTP لتحويل الحروف المخرجة غير صحيحة',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'         => '<var>mbstring.http_output</var> يجب أن تكون <samp>pass</samp>. يمكنك معرفة الإعداد الحالي في صفحة <samp>PHP information</samp>.',
+	
 	'FILES_PER_DAY'	=> 'المرفقات لكل يوم',
 	'FORUM_STATS'	=> 'إحصائيات المنتدى',
 	'GZIP_COMPRESSION'	=> 'ضغط GZip',
