@@ -158,7 +158,8 @@ $lang = array_merge($lang, array(
 	'EMPTY_SUBJECT'	=> 'ينبغي كتابة عنوان للموضوع',
 	'EMPTY_MESSAGE_SUBJECT'	=> 'ينبغي عليك كتابة العنوان عند إنشاء رسالة جديدة',
 	'ENABLED'	=> 'مفعّل',
-	'ENCLOSURE'	=> 'Enclosure',
+	'ENCLOSURE'	=> 'تطويق',
+	'ENTER_USERNAME'               => 'أدخل اسم مستخدم',
 	'ERR_CHANGING_DIRECTORY'	=> 'غير قادر على تغيير الدليل',
 	'ERR_CONNECTING_SERVER'	=> 'خطأ في الاتصال بالخادم',
 	'ERR_JAB_AUTH'	=> 'غير مسموح باستخدام Jabber على الخادم',
@@ -193,6 +194,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'	=> 'رجاءً اضغط لمشاهدة قوانين القسم',
 	'FROM'	=> 'من',
 	'FSOCK_DISABLED'	=> 'لا يمكن إكمال العملية لأن المهمة<var>fsockopen</var> عُطِلَت أو أن الخادم لا يدعم هذا الأمر',
+	'FSOCK_TIMEOUT'         => 'حدث خطأ timeout أثناء قراءة البيانات من الشبكة.',
 	'FTP_FSOCK_HOST'	=> 'مستضيف FTP',
 	'FTP_FSOCK_HOST_EXPLAIN'	=> 'مستضيف FTP المستخدم للاتصال بموقعك',
 	'FTP_FSOCK_PASSWORD'	=> 'كلمة مرور FTP',
@@ -303,7 +305,6 @@ $lang = array_merge($lang, array(
 	'LOGOUT'	=> 'تسجيل الخروج',
 	'LOGOUT_USER'	=> 'تسجيل خروج [ %s ]',
 	'LOG_ME_IN'	=> 'الدخول تلقائياً',
-
 	'MARK'	=> 'تحديد',
 	'MARK_ALL'	=> 'تحديد الكل',
 	'MARK_FORUMS_READ'	=> 'اعتبر جميع المنتديات مقروءة',
@@ -619,6 +620,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'	=> '<strong>%d</strong> رسالة/رسائل غير مقروءة',
 	'UNREAD_POST'         => 'مشاركة غير مقروءة',
     'UNREAD_POSTS'         => 'مشاركات غير مقروءة',
+	'UNWATCH_FORUM_CONFIRM'      => 'هل انت متأكد أنك تريد أن تلغي اشتراكك في هذا المنتدى؟',
+	'UNWATCH_FORUM_DETAILED'   => 'هل أنت متأكد أنك تريد أن تلغي اشتراكك في المنتدى “%s”؟',
+	'UNWATCH_TOPIC_CONFIRM'      => 'هل أنت متأكد أنك تريد أن تلغي اشتراكك في هذا الموضوع؟',
+	'UNWATCH_TOPIC_DETAILED'   => 'هل أنت متأكد أنك تريد أن تلغي اشتراكك في الموضوع “%s”؟',
 	'UNWATCHED_FORUMS'	=> 'لم تعد مشتركا في المنتديات المحددة',
 	'UNWATCHED_TOPICS'	=> 'لم تعد مشتركا في المواضيع المحددة',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'لم تعد مشتركاً في المنتديات والمواضيع التي حددتها',
@@ -664,6 +669,12 @@ $lang = array_merge($lang, array(
 	'VISIT_WEBSITE'	=> 'زيارة الموقع',
 	'WARNINGS'	=> 'تحذيرات',
 	'WARN_USER'	=> 'تحذير العضو',
+	
+	'WATCH_FORUM_CONFIRM'   => 'هل أنت متأكد انك تريد أن تشترك في هذا المنتدى؟',
+	'WATCH_FORUM_DETAILED'   => 'هل أنت متأكد أنك تريد أن تشترك في المنتدى “%s”؟',
+	'WATCH_TOPIC_CONFIRM'   => 'هل أنت متأكد أنك تريد أن تشترك في هذا الموضوع؟',
+	'WATCH_TOPIC_DETAILED'   => 'هل أنت متأكد أنك تريد أن تشترك في الموضوع “%s”؟',
+
 	'WELCOME_SUBJECT'	=> 'أهلا وسهلا بك في منتديات %s',
 	'WEBSITE'	=> 'WWW',
 	'WHOIS'	=> 'Whois',
