@@ -127,6 +127,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'	=> 'الصورة الحالية',
 	'CURRENT_PASSWORD'	=> 'كلمة المرور الحالية',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'عليك كتابة كلمة المرور الحالية في حال الرغبة بتغييرها أو تغيير البريد أو اسم المستخدم',
+	'CUR_PASSWORD_EMPTY'      => 'لم تقم بإدخال كلمة مرورك الحالية.',
 	'CUR_PASSWORD_ERROR'	=> 'كلمة المرور الحالية التي أدخلتها خاطئة',
 	'CUSTOM_DATEFORMAT'	=> 'مخصص',
 	'DEFAULT_ACTION'	=> 'عمل افتراضي',
@@ -246,9 +247,11 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'	=> 'حصل خطأ أثناء نقل الرسائل إلى المجلد الجديد، فقط %1d من أصل %2d رسائل تم نقلها',
 	'MOVE_TO_FOLDER'	=> 'نقل إلى مجلد',
 	'MOVE_UP'	=> 'تحريك للأعلى',
+	'NEW_EMAIL_CONFIRM_EMPTY'      => 'لم تقم بإدخال تأكيد بريدك الاكتروني.',
 	'NEW_EMAIL_ERROR'	=> 'البريد الإلكتروني المدخل غير متطابق',
 	'NEW_FOLDER_NAME'	=> 'اسم مجلد جديد',
 	'NEW_PASSWORD'	=> 'كلمة مرور جديدة',
+	'NEW_PASSWORD_CONFIRM_EMPTY'   => 'لم تقم بإدخال تأكيد كلمة المرور.',
 	'NEW_PASSWORD_ERROR'	=> 'كلمة المرور التي أدخلتها غير متطابقة',
 	'NOTIFY_METHOD'	=> 'طريقة الإشعار',
 	'NOTIFY_METHOD_BOTH'	=> 'الكل',
